@@ -1,6 +1,7 @@
 # flake8: noqa: F401
 from functools import wraps
 
+from rest_framework.exceptions import APIException
 from rest_framework.request import Request
 
 from django_large_image import utilities
@@ -10,10 +11,26 @@ from django_large_image.rest.standalone import ListColormapsView, ListTileSource
 from django_large_image.rest.tiles import Tiles
 
 
-class LargeImageViewMixin(Data, MetaData, Tiles):
+class BaseLargeImageViewMixin(Data, MetaData, Tiles):
     pass
 
 
+class LargeImageViewMixin(BaseLargeImageViewMixin):
+    FILE_FIELD_NAME: str = None
+
+    def get_field_file(self):
+        """Get `FileField` using `FILE_FIELD_NAME`."""
+        try:
+            return getattr(self.get_object(), self.FILE_FIELD_NAME)
+        except (AttributeError, TypeError):
+            # Raise 500 server error
+            raise APIException('`FILE_FIELD_NAME` not properly set on viewset class.')
+
+    @wraps(BaseLargeImageViewMixin.get_path)
+    def get_path(self, request: Request, pk: int):
+        return utilities.field_file_to_local_path(self.get_field_file())
+
+
 class LargeImageVSIViewMixin(LargeImageViewMixin):
     USE_VSI: bool = True
 
