@@ -3,12 +3,13 @@ from django.utils.decorators import method_decorator
 from django.views.decorators.cache import cache_page
 from drf_yasg.utils import swagger_auto_schema
 from rest_framework.decorators import action
+from rest_framework.exceptions import ValidationError
 from rest_framework.request import Request
 from rest_framework.response import Response
 
 from django_large_image import tilesource
 from django_large_image.rest import params
-from django_large_image.rest.core import CACHE_TIMEOUT, BaseLargeImageView
+from django_large_image.rest.base import CACHE_TIMEOUT, BaseLargeImageView
 
 
 class Data(BaseLargeImageView):
@@ -20,7 +21,7 @@ class Data(BaseLargeImageView):
     )
     @action(detail=True)
     def thumbnail(self, request: Request, pk: int) -> HttpResponse:
-        source = self._get_tile_source(request, pk)
+        source = self.get_tile_source(request, pk)
         thumb_data, mime_type = source.getThumbnail(encoding='PNG')
         return HttpResponse(thumb_data, content_type=mime_type)
 
@@ -44,7 +45,7 @@ class Data(BaseLargeImageView):
         images, otherwise, must use `pixels`.
 
         """
-        source = self._get_tile_source(request, pk)
+        source = self.get_tile_source(request, pk)
         units = request.query_params.get('units', None)
         encoding = request.query_params.get('encoding', None)
         left = float(request.query_params.get('left'))
@@ -61,8 +62,9 @@ class Data(BaseLargeImageView):
             encoding,
         )
         if not path:
-            # TODO: should this raise error status?
-            return HttpResponse(b'', content_type=mime_type)
+            raise ValidationError(
+                'No output generated, check that the bounds of your ROI overlap source imagery and that your `projection` and `units` are correct.'
+            )
         tile_binary = open(path, 'rb')
         return HttpResponse(tile_binary, content_type=mime_type)
 
@@ -75,7 +77,7 @@ class Data(BaseLargeImageView):
     def pixel(self, request: Request, pk: int) -> Response:
         left = float(request.query_params.get('left'))
         top = float(request.query_params.get('top'))
-        source = self._get_tile_source(request, pk)
+        source = self.get_tile_source(request, pk)
         metadata = source.getPixel(region={'left': int(left), 'top': int(top), 'units': 'pixels'})
         return Response(metadata)
 
@@ -93,7 +95,7 @@ class Data(BaseLargeImageView):
             density=request.query_params.get('density', False),
             format=request.query_params.get('format', None),
         )
-        source = self._get_tile_source(request, pk)
+        source = self.get_tile_source(request, pk)
         result = source.histogram(**kwargs)
         result = result['histogram']
         for entry in result:
